var searchData=
[
  ['opus',['Opus',['../index.html',1,'']]],
  ['opus_2eh',['opus.h',['../opus_8h.html',1,'']]],
  ['opus_5falloc_5ffail',['OPUS_ALLOC_FAIL',['../group__opus__errorcodes.html#ga92fae6b1de2ac16b8d96561f9a8fb8b9',1,'opus_defines.h']]],
  ['opus_5fapplication_5faudio',['OPUS_APPLICATION_AUDIO',['../group__opus__ctlvalues.html#ga5909f7cb35c04f1110026c6889edd345',1,'opus_defines.h']]],
  ['opus_5fapplication_5frestricted_5flowdelay',['OPUS_APPLICATION_RESTRICTED_LOWDELAY',['../group__opus__ctlvalues.html#ga592232fb39db60c1369989c5c5d19a07',1,'opus_defines.h']]],
  ['opus_5fapplication_5fvoip',['OPUS_APPLICATION_VOIP',['../group__opus__ctlvalues.html#ga07884aa018303a419d1f7acb2f3fa669',1,'opus_defines.h']]],
  ['opus_5fauto',['OPUS_AUTO',['../group__opus__ctlvalues.html#ga1c5b3244b018ff4548d2d6bffa418472',1,'opus_defines.h']]],
  ['opus_5fbad_5farg',['OPUS_BAD_ARG',['../group__opus__errorcodes.html#gaf2d43e479455a1a3b6874e5faf4e827d',1,'opus_defines.h']]],
  ['opus_5fbandwidth_5ffullband',['OPUS_BANDWIDTH_FULLBAND',['../group__opus__ctlvalues.html#ga74cb052d8ec36cbcc9708c417558ebdd',1,'opus_defines.h']]],
  ['opus_5fbandwidth_5fmediumband',['OPUS_BANDWIDTH_MEDIUMBAND',['../group__opus__ctlvalues.html#ga53a2aff4dc0ee23682927ca568c422a3',1,'opus_defines.h']]],
  ['opus_5fbandwidth_5fnarrowband',['OPUS_BANDWIDTH_NARROWBAND',['../group__opus__ctlvalues.html#ga607dd310958b9c7d545d005e4572d47f',1,'opus_defines.h']]],
  ['opus_5fbandwidth_5fsuperwideband',['OPUS_BANDWIDTH_SUPERWIDEBAND',['../group__opus__ctlvalues.html#ga41f86df35af0033a7361895da88671c1',1,'opus_defines.h']]],
  ['opus_5fbandwidth_5fwideband',['OPUS_BANDWIDTH_WIDEBAND',['../group__opus__ctlvalues.html#gac698e5d1281a3632251d2a4ead48afb9',1,'opus_defines.h']]],
  ['opus_5fbitrate_5fmax',['OPUS_BITRATE_MAX',['../group__opus__ctlvalues.html#gaeadbaa3b4b9e15d39cd1d6e7d91519e5',1,'opus_defines.h']]],
  ['opus_5fbuffer_5ftoo_5fsmall',['OPUS_BUFFER_TOO_SMALL',['../group__opus__errorcodes.html#gacd897c05563ec04a67d8e92ba29f3d4f',1,'opus_defines.h']]],
  ['opus_20custom',['Opus Custom',['../group__opus__custom.html',1,'']]],
  ['opus_5fcustom_2eh',['opus_custom.h',['../opus__custom_8h.html',1,'']]],
  ['opus_5fcustom_5fdecode',['opus_custom_decode',['../group__opus__custom.html#gafb6d3b90eed41b938009f4a32d633363',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecode_5ffloat',['opus_custom_decode_float',['../group__opus__custom.html#gac2c34002d4f546a535125e2780c81656',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecoder_5fcreate',['opus_custom_decoder_create',['../group__opus__custom.html#ga16e5e655999536285638cac5e80673db',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecoder_5fctl',['opus_custom_decoder_ctl',['../group__opus__custom.html#ga88b9248e497f3c1b894f035011c569a9',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecoder_5fdestroy',['opus_custom_decoder_destroy',['../group__opus__custom.html#ga0e59e6389bd6478e9c3be48aff4459e1',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecoder_5fget_5fsize',['opus_custom_decoder_get_size',['../group__opus__custom.html#gabe5d6f5f85dcad3ce8b88fe4b2642d2b',1,'opus_custom.h']]],
  ['opus_5fcustom_5fdecoder_5finit',['opus_custom_decoder_init',['../group__opus__custom.html#gad4cb362035313c8f77c24cd29dd0932b',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencode',['opus_custom_encode',['../group__opus__custom.html#ga21d6b0c4106ed5777a8632eed97d4cdc',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencode_5ffloat',['opus_custom_encode_float',['../group__opus__custom.html#ga9403d7a1fc09a0e49692a7f93decee21',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencoder_5fcreate',['opus_custom_encoder_create',['../group__opus__custom.html#ga5aa778f7b0d93b397c1c0fb04b59eb02',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencoder_5fctl',['opus_custom_encoder_ctl',['../group__opus__custom.html#gacf3d854e681cae3b693ee56b54459226',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencoder_5fdestroy',['opus_custom_encoder_destroy',['../group__opus__custom.html#ga5ed5b55bccdc141632d8ba65b8228e7d',1,'opus_custom.h']]],
  ['opus_5fcustom_5fencoder_5fget_5fsize',['opus_custom_encoder_get_size',['../group__opus__custom.html#ga42f50e7f2942144c18c321f00f358ba0',1,'opus_custom.h']]],
  ['opus_5fcustom_5fexport',['OPUS_CUSTOM_EXPORT',['../opus__custom_8h.html#a92c66b86b701421b674984559e79bbf0',1,'opus_custom.h']]],
  ['opus_5fcustom_5fexport_5fstatic',['OPUS_CUSTOM_EXPORT_STATIC',['../opus__custom_8h.html#a83ea1aac7766a02abc5c666516b2e622',1,'opus_custom.h']]],
  ['opus_5fcustom_5fmode_5fcreate',['opus_custom_mode_create',['../group__opus__custom.html#ga8d6683d0b9f2990a8f54d8bafe4f4027',1,'opus_custom.h']]],
  ['opus_5fcustom_5fmode_5fdestroy',['opus_custom_mode_destroy',['../group__opus__custom.html#ga1333ad19db2acd8edf558ac6365741de',1,'opus_custom.h']]],
  ['opus_5fdecode',['opus_decode',['../group__opus__decoder.html#ga7d1111f64c36027ddcb81799df9b3fc9',1,'opus.h']]],
  ['opus_5fdecode_5ffloat',['opus_decode_float',['../group__opus__decoder.html#ga9c554b8c0214e24733a299fe53bb3bd2',1,'opus.h']]],
  ['opus_20decoder',['Opus Decoder',['../group__opus__decoder.html',1,'']]],
  ['opus_5fdecoder_5fcreate',['opus_decoder_create',['../group__opus__decoder.html#ga753f6fe0b699c81cfd47d70c8e15a0bd',1,'opus.h']]],
  ['opus_5fdecoder_5fctl',['opus_decoder_ctl',['../group__opus__decoder.html#ga2d492844b4f66e7f34d85870f13d4846',1,'opus.h']]],
  ['opus_5fdecoder_5fdestroy',['opus_decoder_destroy',['../group__opus__decoder.html#gafebf4cb3c29c9317cac385446a76e36e',1,'opus.h']]],
  ['opus_5fdecoder_5fget_5fnb_5fsamples',['opus_decoder_get_nb_samples',['../group__opus__decoder.html#ga659135a16060f85908f63443a2325118',1,'opus.h']]],
  ['opus_5fdecoder_5fget_5fsize',['opus_decoder_get_size',['../group__opus__decoder.html#gac918415b2ee21add75b7f867ce235011',1,'opus.h']]],
  ['opus_5fdecoder_5finit',['opus_decoder_init',['../group__opus__decoder.html#ga939156d1f561c4273d5c62fa9c235a01',1,'opus.h']]],
  ['opus_5fdefines_2eh',['opus_defines.h',['../opus__defines_8h.html',1,'']]],
  ['opus_5fencode',['opus_encode',['../group__opus__encoder.html#gad2d6bf6a9ffb6674879d7605ed073e25',1,'opus.h']]],
  ['opus_5fencode_5ffloat',['opus_encode_float',['../group__opus__encoder.html#ga4ae9905859cd241ef4bb5c59cd5e5309',1,'opus.h']]],
  ['opus_20encoder',['Opus Encoder',['../group__opus__encoder.html',1,'']]],
  ['opus_5fencoder_5fcreate',['opus_encoder_create',['../group__opus__encoder.html#gaa89264fd93c9da70362a0c9b96b9ca88',1,'opus.h']]],
  ['opus_5fencoder_5fctl',['opus_encoder_ctl',['../group__opus__encoder.html#ga164cbb0425238961919adf1db67949df',1,'opus.h']]],
  ['opus_5fencoder_5fdestroy',['opus_encoder_destroy',['../group__opus__encoder.html#ga5f4c05b4b51cdffec5a55dbf17bbfa1c',1,'opus.h']]],
  ['opus_5fencoder_5fget_5fsize',['opus_encoder_get_size',['../group__opus__encoder.html#gaefeb7dc1d6e3b59dea5ea674c86e9c18',1,'opus.h']]],
  ['opus_5fencoder_5finit',['opus_encoder_init',['../group__opus__encoder.html#ga515db1c267a7421dacaad3610f79eb79',1,'opus.h']]],
  ['opus_5fframesize_5f100_5fms',['OPUS_FRAMESIZE_100_MS',['../group__opus__ctlvalues.html#ga0ac306775a5e3000917110928385f9b0',1,'opus_defines.h']]],
  ['opus_5fframesize_5f10_5fms',['OPUS_FRAMESIZE_10_MS',['../group__opus__ctlvalues.html#ga39d5606c61c4cd21e6ae2f1259a1f15f',1,'opus_defines.h']]],
  ['opus_5fframesize_5f120_5fms',['OPUS_FRAMESIZE_120_MS',['../group__opus__ctlvalues.html#gaeae3c8841942991e3c0ff763113e99ce',1,'opus_defines.h']]],
  ['opus_5fframesize_5f20_5fms',['OPUS_FRAMESIZE_20_MS',['../group__opus__ctlvalues.html#gacfce47959bdaa8581fdc68cec3be2bfb',1,'opus_defines.h']]],
  ['opus_5fframesize_5f2_5f5_5fms',['OPUS_FRAMESIZE_2_5_MS',['../group__opus__ctlvalues.html#ga4696f62216f4afb1493471bb4c25baea',1,'opus_defines.h']]],
  ['opus_5fframesize_5f40_5fms',['OPUS_FRAMESIZE_40_MS',['../group__opus__ctlvalues.html#ga268935a23f6d8a8ae6bb3d11ac6ae172',1,'opus_defines.h']]],
  ['opus_5fframesize_5f5_5fms',['OPUS_FRAMESIZE_5_MS',['../group__opus__ctlvalues.html#gab2e88add9d69a0828ca23efc7bbb41be',1,'opus_defines.h']]],
  ['opus_5fframesize_5f60_5fms',['OPUS_FRAMESIZE_60_MS',['../group__opus__ctlvalues.html#gac8178be7f02dc908c022cc3bb5c6c252',1,'opus_defines.h']]],
  ['opus_5fframesize_5f80_5fms',['OPUS_FRAMESIZE_80_MS',['../group__opus__ctlvalues.html#ga2d9c1118aaaa1adfc5e08ffde36b24eb',1,'opus_defines.h']]],
  ['opus_5fframesize_5farg',['OPUS_FRAMESIZE_ARG',['../group__opus__ctlvalues.html#ga0371f264203138ca92a3705c9c0ac39d',1,'opus_defines.h']]],
  ['opus_5fget_5fapplication',['OPUS_GET_APPLICATION',['../group__opus__encoderctls.html#ga062ebbc209caf6832fe4a309a459fd4c',1,'opus_defines.h']]],
  ['opus_5fget_5fbandwidth',['OPUS_GET_BANDWIDTH',['../group__opus__genericctls.html#ga29db1d9b5e670debec54d1163ad2ec62',1,'opus_defines.h']]],
  ['opus_5fget_5fbitrate',['OPUS_GET_BITRATE',['../group__opus__encoderctls.html#ga1427a5560cbc7e9a59f986d89c05082c',1,'opus_defines.h']]],
  ['opus_5fget_5fcomplexity',['OPUS_GET_COMPLEXITY',['../group__opus__encoderctls.html#ga89755ee721a38d964c7630a920eb27d2',1,'opus_defines.h']]],
  ['opus_5fget_5fdtx',['OPUS_GET_DTX',['../group__opus__encoderctls.html#gaafbb44454e9f57232b85e4e087337ded',1,'opus_defines.h']]],
  ['opus_5fget_5fexpert_5fframe_5fduration',['OPUS_GET_EXPERT_FRAME_DURATION',['../group__opus__encoderctls.html#gab22cbb0bccdd29f58a858c0b3c10756a',1,'opus_defines.h']]],
  ['opus_5fget_5ffinal_5frange',['OPUS_GET_FINAL_RANGE',['../group__opus__genericctls.html#ga1108a508aa475f964d247c1b04d26d89',1,'opus_defines.h']]],
  ['opus_5fget_5fforce_5fchannels',['OPUS_GET_FORCE_CHANNELS',['../group__opus__encoderctls.html#ga21f010167c5dfa1b53f20c46d473e86a',1,'opus_defines.h']]],
  ['opus_5fget_5fgain',['OPUS_GET_GAIN',['../group__opus__decoderctls.html#ga00ca8b4bd753a837f143ebd8ed63d247',1,'opus_defines.h']]],
  ['opus_5fget_5fin_5fdtx',['OPUS_GET_IN_DTX',['../group__opus__genericctls.html#ga9af68dcfb4f136dd91b1050658d559ca',1,'opus_defines.h']]],
  ['opus_5fget_5finband_5ffec',['OPUS_GET_INBAND_FEC',['../group__opus__encoderctls.html#gaf792b27a6277ddf786413dbf472d0ac8',1,'opus_defines.h']]],
  ['opus_5fget_5flast_5fpacket_5fduration',['OPUS_GET_LAST_PACKET_DURATION',['../group__opus__decoderctls.html#ga8f3d070f56b75f2a7af54e5776b387fa',1,'opus_defines.h']]],
  ['opus_5fget_5flookahead',['OPUS_GET_LOOKAHEAD',['../group__opus__encoderctls.html#gaf81b9e01501910adc67195ebb42b4a54',1,'opus_defines.h']]],
  ['opus_5fget_5flsb_5fdepth',['OPUS_GET_LSB_DEPTH',['../group__opus__encoderctls.html#gab5ecdfbbbabfaefc2f2ca79cf4a3b08f',1,'opus_defines.h']]],
  ['opus_5fget_5fmax_5fbandwidth',['OPUS_GET_MAX_BANDWIDTH',['../group__opus__encoderctls.html#gaa3b5736de64792e1144ce12dfb87613c',1,'opus_defines.h']]],
  ['opus_5fget_5fpacket_5floss_5fperc',['OPUS_GET_PACKET_LOSS_PERC',['../group__opus__encoderctls.html#gaa79261c6a55444993fca8d3a3a29d519',1,'opus_defines.h']]],
  ['opus_5fget_5fphase_5finversion_5fdisabled',['OPUS_GET_PHASE_INVERSION_DISABLED',['../group__opus__genericctls.html#gae9ad2f51fe4fe086f35e881682c4c247',1,'opus_defines.h']]],
  ['opus_5fget_5fpitch',['OPUS_GET_PITCH',['../group__opus__decoderctls.html#gaa89fc25eb35fc31a02b508562dd83820',1,'opus_defines.h']]],
  ['opus_5fget_5fprediction_5fdisabled',['OPUS_GET_PREDICTION_DISABLED',['../group__opus__encoderctls.html#ga6f174467d0e244917d1cc736f9033f1d',1,'opus_defines.h']]],
  ['opus_5fget_5fsample_5frate',['OPUS_GET_SAMPLE_RATE',['../group__opus__genericctls.html#gac8ad425424211faae6a0fbfb7c28bb51',1,'opus_defines.h']]],
  ['opus_5fget_5fsignal',['OPUS_GET_SIGNAL',['../group__opus__encoderctls.html#ga640d434de535e2d2caec991c347303a4',1,'opus_defines.h']]],
  ['opus_5fget_5fvbr',['OPUS_GET_VBR',['../group__opus__encoderctls.html#ga58feba30c167962305ec268e6abe8c08',1,'opus_defines.h']]],
  ['opus_5fget_5fvbr_5fconstraint',['OPUS_GET_VBR_CONSTRAINT',['../group__opus__encoderctls.html#gab35fa5691ba0dd932031b7839c47513c',1,'opus_defines.h']]],
  ['opus_5fget_5fversion_5fstring',['opus_get_version_string',['../group__opus__libinfo.html#ga3cd7aa16259a46f37a44d2e823b131e5',1,'opus_defines.h']]],
  ['opus_5fint',['opus_int',['../opus__types_8h.html#af3ad92331bd12b4fb4ffd0f63599d76a',1,'opus_types.h']]],
  ['opus_5fint16',['opus_int16',['../opus__types_8h.html#acc9ed7cf60479eb81f9648c6ec27dc26',1,'opus_types.h']]],
  ['opus_5fint32',['opus_int32',['../opus__types_8h.html#aa4d309d6f80b99dbabebc8f98879ab9a',1,'opus_types.h']]],
  ['opus_5fint64',['opus_int64',['../opus__types_8h.html#ab6742070cf9d0ccffca2b80522b4f41a',1,'opus_types.h']]],
  ['opus_5fint8',['opus_int8',['../opus__types_8h.html#aa3680a0b88ed316512ba749abe4c11c5',1,'opus_types.h']]],
  ['opus_5finternal_5ferror',['OPUS_INTERNAL_ERROR',['../group__opus__errorcodes.html#gae1f952c366ebd380df9efa1842635a0b',1,'opus_defines.h']]],
  ['opus_5finvalid_5fpacket',['OPUS_INVALID_PACKET',['../group__opus__errorcodes.html#ga46fc9dd493fb8e291bd8e838f0988bb7',1,'opus_defines.h']]],
  ['opus_5finvalid_5fstate',['OPUS_INVALID_STATE',['../group__opus__errorcodes.html#ga54416ec79619179d688918f25e9b20e3',1,'opus_defines.h']]],
  ['opus_20library_20information_20functions',['Opus library information functions',['../group__opus__libinfo.html',1,'']]],
  ['opus_20multistream_20api',['Opus Multistream API',['../group__opus__multistream.html',1,'']]],
  ['opus_5fmultistream_2eh',['opus_multistream.h',['../opus__multistream_8h.html',1,'']]],
  ['opus_5fmultistream_5fdecode',['opus_multistream_decode',['../group__opus__multistream.html#gaa4b89541efe01970cf52e4a336db3ad0',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecode_5ffloat',['opus_multistream_decode_float',['../group__opus__multistream.html#ga620e67c67872f8ea0b67a200c729630a',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecoder_5fcreate',['opus_multistream_decoder_create',['../group__opus__multistream.html#ga3c0e342774174c471e61cedba53755c9',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecoder_5fctl',['opus_multistream_decoder_ctl',['../group__opus__multistream.html#ga4b3dca8d46e5868cc133f3f6d2b57688',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecoder_5fdestroy',['opus_multistream_decoder_destroy',['../group__opus__multistream.html#gaaec72b484eabc78d7869221c6d2ce080',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecoder_5fget_5fsize',['opus_multistream_decoder_get_size',['../group__opus__multistream.html#ga38d745963e7903890c80278bc2569c39',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fdecoder_5finit',['opus_multistream_decoder_init',['../group__opus__multistream.html#ga09a4d14fc497d4f6fbe76bd1c5d45436',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencode',['opus_multistream_encode',['../group__opus__multistream.html#ga9e1000f220d9872e9f3b6e4f2417b445',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencode_5ffloat',['opus_multistream_encode_float',['../group__opus__multistream.html#gaff832211e572536941b9d6094f9f42ce',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencoder_5fcreate',['opus_multistream_encoder_create',['../group__opus__multistream.html#gaeb64c648ed8155f824ca8d9a93ccecae',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencoder_5fctl',['opus_multistream_encoder_ctl',['../group__opus__multistream.html#gae14328330c548dede66c494f51e33707',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencoder_5fdestroy',['opus_multistream_encoder_destroy',['../group__opus__multistream.html#gaec819b8d4b38350aba6959cee7d33f94',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencoder_5fget_5fsize',['opus_multistream_encoder_get_size',['../group__opus__multistream.html#ga8642aa9cf16115229a655574d832293b',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fencoder_5finit',['opus_multistream_encoder_init',['../group__opus__multistream.html#gae7586aa54c322fd9599de24b5c8b8c01',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fget_5fdecoder_5fstate',['OPUS_MULTISTREAM_GET_DECODER_STATE',['../group__opus__multistream__ctls.html#gaf0843831519b4d9b9d73391afef04a53',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fget_5fencoder_5fstate',['OPUS_MULTISTREAM_GET_ENCODER_STATE',['../group__opus__multistream__ctls.html#ga4e67607eb691c4314a5de90d8c58aff0',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fpacket_5fpad',['opus_multistream_packet_pad',['../group__opus__repacketizer.html#gad3559b66569ca4561fe4ba8f3b1cb336',1,'opus.h']]],
  ['opus_5fmultistream_5fpacket_5funpad',['opus_multistream_packet_unpad',['../group__opus__repacketizer.html#gaa0f0e05884b48b2f901977478e74e067',1,'opus.h']]],
  ['opus_5fmultistream_5fsurround_5fencoder_5fcreate',['opus_multistream_surround_encoder_create',['../group__opus__multistream.html#ga8d87c08ecbe6ed4ce1ede4e58718b621',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fsurround_5fencoder_5fget_5fsize',['opus_multistream_surround_encoder_get_size',['../group__opus__multistream.html#ga9bed3af8a080ab97b8af48007758fa14',1,'opus_multistream.h']]],
  ['opus_5fmultistream_5fsurround_5fencoder_5finit',['opus_multistream_surround_encoder_init',['../group__opus__multistream.html#ga993bfbae18b2dbfd641e50e51cef4484',1,'opus_multistream.h']]],
  ['opus_5fok',['OPUS_OK',['../group__opus__errorcodes.html#gaa44cf8a185e1b5cb940ef63eb4f02d21',1,'opus_defines.h']]],
  ['opus_5fpacket_5fget_5fbandwidth',['opus_packet_get_bandwidth',['../group__opus__decoder.html#ga89b9375b6ff5e15f07fdc5d0cf4f0053',1,'opus.h']]],
  ['opus_5fpacket_5fget_5fnb_5fchannels',['opus_packet_get_nb_channels',['../group__opus__decoder.html#ga4209376ddf8cc3379767e1749e1ef26d',1,'opus.h']]],
  ['opus_5fpacket_5fget_5fnb_5fframes',['opus_packet_get_nb_frames',['../group__opus__decoder.html#ga064cb2ed9e77a934cd7db6c13b02c584',1,'opus.h']]],
  ['opus_5fpacket_5fget_5fnb_5fsamples',['opus_packet_get_nb_samples',['../group__opus__decoder.html#ga3cfec8b0bed7789ebd88c3b3370d337b',1,'opus.h']]],
  ['opus_5fpacket_5fget_5fsamples_5fper_5fframe',['opus_packet_get_samples_per_frame',['../group__opus__decoder.html#gab2a955acced631c6cb7876bbdc7953d4',1,'opus.h']]],
  ['opus_5fpacket_5fpad',['opus_packet_pad',['../group__opus__repacketizer.html#ga62eb1a9b887de0ce50f52eacb3609f13',1,'opus.h']]],
  ['opus_5fpacket_5fparse',['opus_packet_parse',['../group__opus__decoder.html#ga9d0054936a3345865632b04729cd368c',1,'opus.h']]],
  ['opus_5fpacket_5funpad',['opus_packet_unpad',['../group__opus__repacketizer.html#ga0f0d860cce598033814071327b626ecf',1,'opus.h']]],
  ['opus_5fpcm_5fsoft_5fclip',['opus_pcm_soft_clip',['../group__opus__decoder.html#gaff99598b352e8939dded08d96e125e0b',1,'opus.h']]],
  ['opus_5frepacketizer_5fcat',['opus_repacketizer_cat',['../group__opus__repacketizer.html#ga2840dd56bfa37f8c6874355b9ce8fb46',1,'opus.h']]],
  ['opus_5frepacketizer_5fcreate',['opus_repacketizer_create',['../group__opus__repacketizer.html#ga6f8813666ef851550ecf8658a731ff7d',1,'opus.h']]],
  ['opus_5frepacketizer_5fdestroy',['opus_repacketizer_destroy',['../group__opus__repacketizer.html#gadb08b25d2a29a559c35774cfe2a1b886',1,'opus.h']]],
  ['opus_5frepacketizer_5fget_5fnb_5fframes',['opus_repacketizer_get_nb_frames',['../group__opus__repacketizer.html#ga2cad98d04458aafdf6bb9f22f34ea7c0',1,'opus.h']]],
  ['opus_5frepacketizer_5fget_5fsize',['opus_repacketizer_get_size',['../group__opus__repacketizer.html#ga35c8fc05764748d187c62fc50e812d06',1,'opus.h']]],
  ['opus_5frepacketizer_5finit',['opus_repacketizer_init',['../group__opus__repacketizer.html#gab42ff7c3f8a49ff5029fcf60f3b853f0',1,'opus.h']]],
  ['opus_5frepacketizer_5fout',['opus_repacketizer_out',['../group__opus__repacketizer.html#ga19ff1e91a8fa652380f972a224a26481',1,'opus.h']]],
  ['opus_5frepacketizer_5fout_5frange',['opus_repacketizer_out_range',['../group__opus__repacketizer.html#gac591b550d92125b4abfa11a4b609f51f',1,'opus.h']]],
  ['opus_5freset_5fstate',['OPUS_RESET_STATE',['../group__opus__genericctls.html#gadc74e4fa8bcdf9994187d52d92207337',1,'opus_defines.h']]],
  ['opus_5fset_5fapplication',['OPUS_SET_APPLICATION',['../group__opus__encoderctls.html#ga18fa17dae52ff8f3eaea314204bf1a36',1,'opus_defines.h']]],
  ['opus_5fset_5fbandwidth',['OPUS_SET_BANDWIDTH',['../group__opus__encoderctls.html#ga0178dabe5526d5b0667d81489cc93791',1,'opus_defines.h']]],
  ['opus_5fset_5fbitrate',['OPUS_SET_BITRATE',['../group__opus__encoderctls.html#ga0bb51947e355b33d0cb358463b5101a7',1,'opus_defines.h']]],
  ['opus_5fset_5fcomplexity',['OPUS_SET_COMPLEXITY',['../group__opus__encoderctls.html#ga3483877bf1687a75dd4a1de6f85f291c',1,'opus_defines.h']]],
  ['opus_5fset_5fdtx',['OPUS_SET_DTX',['../group__opus__encoderctls.html#ga4f053b2db8c5162293213aabfe123773',1,'opus_defines.h']]],
  ['opus_5fset_5fexpert_5fframe_5fduration',['OPUS_SET_EXPERT_FRAME_DURATION',['../group__opus__encoderctls.html#gab3764c1b899b2bbe435e1168d3e24b6e',1,'opus_defines.h']]],
  ['opus_5fset_5fforce_5fchannels',['OPUS_SET_FORCE_CHANNELS',['../group__opus__encoderctls.html#ga8450a745bd919a8de522afec115f3b5f',1,'opus_defines.h']]],
  ['opus_5fset_5fgain',['OPUS_SET_GAIN',['../group__opus__decoderctls.html#ga8ddb6fa694efa2c7e95ef51addc70dac',1,'opus_defines.h']]],
  ['opus_5fset_5finband_5ffec',['OPUS_SET_INBAND_FEC',['../group__opus__encoderctls.html#ga5b67dc832aa46c1c2f35752c46380545',1,'opus_defines.h']]],
  ['opus_5fset_5flsb_5fdepth',['OPUS_SET_LSB_DEPTH',['../group__opus__encoderctls.html#gaa23940eb477ff617edc14b8d66e104c0',1,'opus_defines.h']]],
  ['opus_5fset_5fmax_5fbandwidth',['OPUS_SET_MAX_BANDWIDTH',['../group__opus__encoderctls.html#ga4f88288e89c595c07c61db316cc45289',1,'opus_defines.h']]],
  ['opus_5fset_5fpacket_5floss_5fperc',['OPUS_SET_PACKET_LOSS_PERC',['../group__opus__encoderctls.html#gafda1c951dea919ba54432cd03827f1a9',1,'opus_defines.h']]],
  ['opus_5fset_5fphase_5finversion_5fdisabled',['OPUS_SET_PHASE_INVERSION_DISABLED',['../group__opus__genericctls.html#ga10fa1f6eab136baf83c232afa989b6a8',1,'opus_defines.h']]],
  ['opus_5fset_5fprediction_5fdisabled',['OPUS_SET_PREDICTION_DISABLED',['../group__opus__encoderctls.html#ga0a73d613f6d9d601b32535fd37f58482',1,'opus_defines.h']]],
  ['opus_5fset_5fsignal',['OPUS_SET_SIGNAL',['../group__opus__encoderctls.html#gaaa87ccee4ae46aa6c9528e03c5122b89',1,'opus_defines.h']]],
  ['opus_5fset_5fvbr',['OPUS_SET_VBR',['../group__opus__encoderctls.html#ga34d09ae06cab7e1a6c49876249b67892',1,'opus_defines.h']]],
  ['opus_5fset_5fvbr_5fconstraint',['OPUS_SET_VBR_CONSTRAINT',['../group__opus__encoderctls.html#gab1b534a4fe55373f1be407ad4b2b22bd',1,'opus_defines.h']]],
  ['opus_5fsignal_5fmusic',['OPUS_SIGNAL_MUSIC',['../group__opus__ctlvalues.html#gaa0c228c664b6d426f4c213e3a5350889',1,'opus_defines.h']]],
  ['opus_5fsignal_5fvoice',['OPUS_SIGNAL_VOICE',['../group__opus__ctlvalues.html#ga085a116fed816373d3b9eae28df49404',1,'opus_defines.h']]],
  ['opus_5fstrerror',['opus_strerror',['../group__opus__libinfo.html#gafad3bac5a05dc7c3477a5765eb5e1873',1,'opus_defines.h']]],
  ['opus_5ftypes_2eh',['opus_types.h',['../opus__types_8h.html',1,'']]],
  ['opus_5fuint',['opus_uint',['../opus__types_8h.html#a495e53c6b5deb68cf24f5c79651bd6c8',1,'opus_types.h']]],
  ['opus_5fuint16',['opus_uint16',['../opus__types_8h.html#a0ab2b1deead8e222cfc659cd855bd8d0',1,'opus_types.h']]],
  ['opus_5fuint32',['opus_uint32',['../opus__types_8h.html#a643eaaadb9ef6cd44308e0299d8cd8ce',1,'opus_types.h']]],
  ['opus_5fuint64',['opus_uint64',['../opus__types_8h.html#a8291e2e41535338d13cd74868cb8e86d',1,'opus_types.h']]],
  ['opus_5fuint8',['opus_uint8',['../opus__types_8h.html#a40a7748a424a3453dc79f3838c5dbddc',1,'opus_types.h']]],
  ['opus_5funimplemented',['OPUS_UNIMPLEMENTED',['../group__opus__errorcodes.html#ga3b8d73b0f44b8b925ff40fd7c02b14a0',1,'opus_defines.h']]],
  ['opuscustomdecoder',['OpusCustomDecoder',['../group__opus__custom.html#gacae60f89c5ce7aeea69503451b9e2e6f',1,'opus_custom.h']]],
  ['opuscustomencoder',['OpusCustomEncoder',['../group__opus__custom.html#ga7abe6a7afc599667950251c987feb439',1,'opus_custom.h']]],
  ['opuscustommode',['OpusCustomMode',['../group__opus__custom.html#gaf33847c711195b9edef896b73c96ec4f',1,'opus_custom.h']]],
  ['opusdecoder',['OpusDecoder',['../group__opus__decoder.html#ga401d8579958d36094715a6b90cd159a6',1,'opus.h']]],
  ['opusencoder',['OpusEncoder',['../group__opus__encoder.html#gaf461a3ef2f10c2fe8b994a176f06c9bd',1,'opus.h']]],
  ['opusmsdecoder',['OpusMSDecoder',['../group__opus__multistream.html#gad3497495deb9a8ace82e76cd4f93e0e4',1,'opus_multistream.h']]],
  ['opusmsencoder',['OpusMSEncoder',['../group__opus__multistream.html#gae5826674d142fc873ebc1d781c507dd7',1,'opus_multistream.h']]],
  ['opusrepacketizer',['OpusRepacketizer',['../group__opus__repacketizer.html#ga1f85070a64bcbf5bf24f5ccb80323e7b',1,'opus.h']]]
];
